/********************************************************/
/* Chinn-Into Index										*/
/* Date: Dec 15, 2015									*/
/* `today' = 20151215 									*/
/* Source >> chinn_ito_updated.dta 						*/
/* 		  >> list_emerging.dta 							*/
/* 														*/
/* Output >> chinn_ito_v`today'.dta						*/
/********************************************************/

set more off
clear all
local today "20151215"

cap log close
log using chinnito_log_`today', replace text

// load Chinn-Indo Index dataset
use chinn_ito_updated.dta, clear

// save a working copy of dataset
save chinn_ito_v`today'.dta, replace

// relabel
rename ccode wbcode
rename cn ifs_code

// retrieve country codes - Initial list of emerging countries
merge m:1 ifs_code using list_emerging, keepusing(emerging piigs) gen(_merge_id) keep(match master)

// adjust classifications
replace piigs = 0 if piigs == .
replace emerging = 0 if emerging == .
replace emerging = 0 if wbcode == "BWA" // excluding Botswana from emerging countries set

// baltic countries
gen baltic = (wbcode == "EST") | (wbcode == "LVA") | (wbcode == "LTU")

// advanced economies
gen advanced = (wbcode == "FRA") | (wbcode == "USA") | (wbcode == "DEU") | (wbcode == "GBR")

// eastern europe & baltic transition countries not classified elsewhere
gen eutrans = (wbcode == "BGR") | (wbcode == "SVK") | (wbcode == "SVN")

// ignore small island economies & small economies
gen ignore = (wbcode == "ABW") | (wbcode == "ANT") | (wbcode == "ATG") | (wbcode == "BHS") | (wbcode == "BLZ") | (wbcode == "BRN") | (wbcode == "CHE") | (wbcode == "COM") | (wbcode == "CPV") | (wbcode == "DMA") | (wbcode == "EUR") | (wbcode == "FJI") | (wbcode == "GMB") | (wbcode == "GRD") | (wbcode == "JOR") | (wbcode == "KHM") | (wbcode == "KIR") | (wbcode == "KNA") | (wbcode == "LCA") | (wbcode == "LUX") | (wbcode == "LSO") | (wbcode == "MDV") | (wbcode == "MLT") | (wbcode == "MUS") |  (wbcode == "PNG") | (wbcode == "SDN") | (wbcode == "SLB") | (wbcode == "SRB") | (wbcode == "STP") | (wbcode == "SUR") |  (wbcode == "SWZ") | (wbcode == "SYC") | (wbcode == "TTO") | (wbcode == "TON") | (wbcode == "VCT") | (wbcode == "VUT") | (wbcode == "WSM") 

// tag opec countries
gen opec = (wbcode == "OMN") | (wbcode == "QAT") | (wbcode == "ABW") | (wbcode == "LBY") | (wbcode == "NGA") | (wbcode == "VEN") | (wbcode == "IRN") | (wbcode == "KWT") | (wbcode == "SAU") | (wbcode == "ARE") | (wbcode == "DZA")  

// drop opec & small island economies
drop if ignore == 1 | opec == 1

// some labels
label var emerging "is emerging"
label define emerginglbl 0 "non emerging", modify
label define emerginglbl 1 "emerging", modify
label values emerging emerginglbl

label var advanced "is advanced"
label define advancedlbl 0 "non advanced", modify
label define advancedlbl 1 "advanced", modify
label values advanced advancedlbl

label var baltic "is baltic"
label define balticlbl 0 "non baltic", modify
label define balticlbl 1 "baltic", modify
label values baltic balticlbl

label var eutrans "is european transition"
label define eutranslbl 0 "non eu transition", modify
label define eutranslbl 1 "eu transition", modify
label values eutrans eutranslbl

label var piigs "is european transition"
label define piigslbl 0 "non eu transition", modify
label define piigslbl 1 "eu transition", modify
label values piigs piigslbl

gen adv_emerging = .
replace adv_emerging = 1 if emerging == 1
replace adv_emerging = 2 if emerging == 0 & advanced == 1
replace adv_emerging = 3 if emerging == 0 & advanced == 0

label var adv_emerging "advanced/emerging/other - excluding islands & opec"
label define adv_emerginglbl 1 "emerging", modify
label define adv_emerginglbl 2 "advanced", modify
label define adv_emerginglbl 3 "nonemerging nonadvanced", modify
label values adv_emerging adv_emerginglbl


gen split_group = .
replace split_group = 1 if emerging == 1
replace split_group = 2 if piigs 	== 1
replace split_group = 3 if baltic 	== 1
replace split_group = 4 if advanced	== 1
replace split_group = 5 if eutrans	== 1

label var split_group "country groups"
label define split_grouplbl 1 "emerging economies", modify
label define split_grouplbl 2 "euro area periphery", modify
label define split_grouplbl 3 "baltic economies", modify
label define split_grouplbl 4 "advanced economies", modify
label define split_grouplbl 5 "eu transition", modify
label values split_group split_grouplbl

// order a few a variables
order wbcode emerging piigs, after(ifs_code)

// set the dataset as a panel dataset
xtset ifs_code year, yearly

/* eras */
gen era = .
replace era = 1 if year <= 1991
replace era = 2 if 1992 <= year & year <= 1996
replace era = 3 if 1997 <= year & year <= 2001
replace era = 4 if 2002 <= year & year <= 2006
replace era = 5 if 2007 <= year & year <= 2011
replace era = 6 if 2012 <= year 
label var era "Era"
label define eralbl 1 " pre 1991", modify
label define eralbl 2 "1992-1996", modify
label define eralbl 3 "1997-2001", modify
label define eralbl 4 "2002-2006", modify
label define eralbl 5 "2007-2011", modify
label define eralbl 6 "post 2012", modify
label values era eralbl

gen yrpre = era == 2
label var yrpre "year 1992-1996"

gen yrpost = era == 4
label var yrpre "year 2002-2006"

egen tag_country = tag(wbcode)
label var tag_country "Country tag"

/* computing era average */
// variables for which we are computing the averages by era
local avgvars "kaopen"

// eras for which we compute averages
local eravals "1 2 3 4 5"

foreach var of local avgvars {
	bysort ifs_code era: egen `var'_avg_era = mean(`var')

	gen _`var'_1 = `var'_avg_era if era == 1 // get mean within era == 1
	bysort ifs_code: egen `var'_old = max(_`var'_1) // copy the mean for all obs.
	format `var'_old %7.2f
	
	gen _`var'_2 = `var'_avg_era if era == 2 // get mean within era == 2
	bysort ifs_code: egen `var'_pre = max(_`var'_2) // copy the mean for all obs.
	format `var'_pre %7.2f
	
	gen _`var'_3 = `var'_avg_era if era == 3 // get mean within era == 3
	bysort ifs_code: egen `var'_btw = max(_`var'_3) // copy the mean for all obs.
	format `var'_btw %7.2f
	
	gen _`var'_4 = `var'_avg_era if era == 4 // get mean within era == 4
	bysort ifs_code: egen `var'_post = max(_`var'_4) // copy the mean for all obs.
	format `var'_post %7.2f

	gen _`var'_5 = `var'_avg_era if era == 5 // get mean within era == 5
	bysort ifs_code: egen `var'_gfc = max(_`var'_5) // copy the mean for all obs.
	format `var'_gfc %7.2f	

	gen _`var'_6 = `var'_avg_era if era == 6 // get mean within era == 6
	bysort ifs_code: egen `var'_now = max(_`var'_6) // copy the mean for all obs.
	format `var'_now %7.2f	
	
	drop _`var'_1 _`var'_2 _`var'_3 _`var'_4 _`var'_5 _`var'_6 // drop these variables used to get the means pre & post

	gen `var'_chg = `var'_post - `var'_pre
	label var `var'_chg "change in avg. `var'"
	format `var'_chg %7.2f

	drop if `var'_chg == . // dismiss cases we don't have data pre or post/
}

// stats
disp("Summary: Capital Openess")
tabstat kaopen if tag_country , by (split_group) stat(mean median N) labelwidth(32) varwidth(16) longstub 

// time average
bysort year adv_emerging: egen kaopen_avg = mean(kaopen)
label var kaopen_avg "avg. capital openness"

// graph - emes
tsline kaopen_avg if adv_emerging == 1 & year <= 2012, ytitle("average Chinn-Ito Index of capital openness") ylabel(-1(.5)0.5,angle(0)) ymtick(-1(.25).5) title("Capital Openness") legend(off) graphregion(fcolor(white)) xtitle("") xlabel(1970(5)2010,angle(0)) xmtick(1970(1)2012) name(chinnito_emes, replace)

graph save chinnito_emes.gph, asis replace
graph export chinnito_emes.eps, as(eps) preview(on) replace

// graph - emes and afes
tsline kaopen_avg if adv_emerging <= 2 & year <= 2012, by(adv_emergin) ytitle("average Chinn-Ito Index of capital openness") ylabel(-1(.5)2.5,angle(0)) ymtick(-1(.25)2.5) title("Capital Openness") legend(off) graphregion(fcolor(white)) xtitle("") xlabel(1970(5)2010,angle(0)) xmtick(1970(1)2012) name(chinnito_emes_afes, replace)

graph save chinnito_emes_afes.gph, asis replace
graph export chinnito_emes_afes.eps, as(eps) preview(on) replace

// graph - emes and baltic
tsline kaopen_avg if (emerging == 1 | baltic == 1) & year <= 2012, by(split_group) ytitle("average Chinn-Ito Index of capital openness") ylabel(-1(.5)2.5,angle(0)) ymtick(-1(.25)2.5) title("Capital Openness") legend(off) graphregion(fcolor(white)) xtitle("") xlabel(1970(5)2010,angle(0)) xmtick(1970(1)2012) name(chinnito_emes_balt, replace)

graph save chinnito_emes_balt.gph, asis replace
graph export chinnito_emes_balt.eps, as(eps) preview(on) replace

// save a working copy of dataset
save chinn_ito_v`today'.dta, replace

log close

