/********************************************************/
/* IFS: Data on BOP & IIP								*/
/* Date: Dec 15, 2015									*/
/* `today' = 20151215 									*/
/* Source  												*/
/* 	  >> ewn2011	 									*/
/* 	  >> ifscode2iso, code_lists,list_emerging 			*/
/* 														*/
/* Output >> iip_hk_v`today'.dta						*/
/********************************************************/

set more off
clear all
set mem 1g

local today "20151215"

cap log close
log using iip_hk_log_`today', replace text


/////////////////////////////////////////
/////// -Lane & Milesi-Ferretti- ////////
/////////////////////////////////////////

// load Lane & Milesi-Ferretti dataset
use ewn2011, clear

// save a working copy of LMF dataset
save iip_hk_v`today'.dta, replace

// keep a subset of the LMF variables
keep country year ifs_code totalliabilities fxreservesminusgold gdpus debtliabilitiesportfoliodebtothe tot_liab_hkp fxreserves_hkp gdpus_hkp extdebt_liab_hkp netforeignassetsnfa

// retrieve country codes - ISO codes
merge m:1 ifs_code using ifscode2iso, keepusing(iso) gen(_merge_iso) keep(match master)

// retrieve country codes - World Bank codes
merge m:1 ifs_code using code_lists, keepusing(wbcode WB_inc) gen(_merge_wb) keep(match master)

// retrieve country codes - Initial list of emerging countries
merge m:1 ifs_code using list_emerging, keepusing(emerging piigs) gen(_merge_id) keep(match master)

replace country = "China, Mainland" if wbcode == "CHN"

// adjust classifications
replace piigs = 0 if piigs == .
replace emerging = 0 if emerging == .
replace emerging = 0 if wbcode == "BWA" // excluding Botswana from emerging countries set

// baltic countries
gen baltic = (wbcode == "EST") | (wbcode == "LVA") | (wbcode == "LTU")

// advanced economies
gen advanced = (wbcode == "FRA") | (wbcode == "USA") | (wbcode == "DEU") | (wbcode == "GBR")

// eastern europe & baltic transition countries not classified elsewhere
gen eutrans = (wbcode == "BGR") | (wbcode == "SVK") | (wbcode == "SVN")

// ignore small island economies & small economies
gen ignore = (wbcode == "ABW") | (wbcode == "ANT") | (wbcode == "ATG") | (wbcode == "BHS") | (wbcode == "BLZ") | (wbcode == "BRN") | (wbcode == "CHE") | (wbcode == "COM") | (wbcode == "CPV") | (wbcode == "DMA") | (wbcode == "EUR") | (wbcode == "FJI") | (wbcode == "GMB") | (wbcode == "GRD") | (wbcode == "JOR") | (wbcode == "KHM") | (wbcode == "KIR") | (wbcode == "KNA") | (wbcode == "LCA") | (wbcode == "LUX") | (wbcode == "LSO") | (wbcode == "MDV") | (wbcode == "MLT") | (wbcode == "MUS") |  (wbcode == "PNG") | (wbcode == "SDN") | (wbcode == "SLB") | (wbcode == "SRB") | (wbcode == "STP") | (wbcode == "SUR") |  (wbcode == "SWZ") | (wbcode == "SYC") | (wbcode == "TTO") | (wbcode == "TON") | (wbcode == "VCT") | (wbcode == "VUT") | (wbcode == "WSM") 

// tag opec countries
gen opec = (wbcode == "OMN") | (wbcode == "QAT") | (wbcode == "ABW") | (wbcode == "LBY") | (wbcode == "NGA") | (wbcode == "VEN") | (wbcode == "IRN") | (wbcode == "KWT") | (wbcode == "SAU") | (wbcode == "ARE") | (wbcode == "DZA")  

// drop opec & small island economies
drop if ignore == 1 | opec == 1

// some labels
label var emerging "is emerging"
label define emerginglbl 0 "non emerging", modify
label define emerginglbl 1 "emerging", modify
label values emerging emerginglbl

label var advanced "is advanced"
label define advancedlbl 0 "non advanced", modify
label define advancedlbl 1 "advanced", modify
label values advanced advancedlbl

label var baltic "is baltic"
label define balticlbl 0 "non baltic", modify
label define balticlbl 1 "baltic", modify
label values baltic balticlbl

label var eutrans "is european transition"
label define eutranslbl 0 "non eu transition", modify
label define eutranslbl 1 "eu transition", modify
label values eutrans eutranslbl

label var piigs "is european transition"
label define piigslbl 0 "non eu transition", modify
label define piigslbl 1 "eu transition", modify
label values piigs piigslbl

gen adv_emerging = .
replace adv_emerging = 1 if emerging == 1
replace adv_emerging = 2 if emerging == 0 & advanced == 1
replace adv_emerging = 3 if emerging == 0 & advanced == 0

label var adv_emerging "advanced/emerging/other - excluding islands & opec"
label define adv_emerginglbl 1 "emerging", modify
label define adv_emerginglbl 2 "advanced", modify
label define adv_emerginglbl 3 "nonemerging nonadvanced", modify
label values adv_emerging adv_emerginglbl


gen split_group = .
replace split_group = 1 if emerging == 1
replace split_group = 2 if piigs 	== 1
replace split_group = 3 if baltic 	== 1
replace split_group = 4 if advanced	== 1
replace split_group = 5 if eutrans	== 1

label var split_group "country groups"
label define split_grouplbl 1 "emerging economies", modify
label define split_grouplbl 2 "euro area periphery", modify
label define split_grouplbl 3 "baltic economies", modify
label define split_grouplbl 4 "advanced economies", modify
label define split_grouplbl 5 "eu transition", modify
label values split_group split_grouplbl

// order a few a variables
order iso wbcode emerging piigs, after(ifs_code)

// set the dataset as a panel dataset
xtset ifs_code year, yearly

save iip_hk_v`today'.dta, replace

/////////////////////////////////////////
/////// -Hur and Kondo measures -////////
/////////////////////////////////////////

/* GDP */
//gen gdp = gdpus
gen gdp = gdpus_hkp
label var gdp "GDP in UDS"
format gdp %7.2f

/* Reserves */
//gen res = fxreservesminusgold
gen res = fxreserves_hkp
label var res "Reserves"
format res %7.2f

/* Debt liabilities */
//gen debtliab = debtliabilitiesportfoliodebtothe
gen debtliab = extdebt_liab_hkp
label var debtliab "External debt liabilities"
format debtliab %7.2f

/* Total liabilities */
//gen debtliab = totalliabilities
gen totliab = tot_liab_hkp
label var totliab "External liabilities"
format totliab %7.2f

/* Reserves to GDP ratio */
gen res_gdp = 100*res/gdpus_hkp
label var res_gdp "Reserves to GDP"
format res_gdp %7.2f

/* Reserves to External Liabilities ratio */
// Total liabilities= FDI liabilities+portfolio equity liabilities+debt liabilities+derivatives liabilities
gen res_liab = 100*res/totliab
label var res_liab "Reserves to External liabilities"
format res_liab %7.2f

/* Reserves to External Debt Liabilities ratio */
// The series "debt assets" and "debt liabilities" include the sum of "portfolio debt securities" and "other investment" (but not FDI intercompany debt, which is in the FDI statistics)
gen res_debtliab = 100*res/debtliab
label var res_debtliab "Reserves to External debt liabilities"
format res_debtliab %7.2f

/* Debt liabilities to GDP ratio */
gen debtliab_gdp = 100*debtliab/gdp
label var debtliab_gdp "External debt liabilities to GDP"
format debtliab_gdp %7.2f

/* Change in Total liabilities */
gen liab_chg = D.totliab
label var liab_chg "Change in Total liabilities"
format liab_chg %7.2f

/* Change in Debt liabilities */
gen debtliab_chg = D.debtliab
label var debtliab_chg "Change in External debt liabilities"
format debtliab_chg %7.2f

/* Change in Reserves */
gen res_chg = D.res
label var res_chg "Change in Reserves"
format res_chg %7.2f

/* eras */

gen era = .
replace era = 1 if year <= 1991
replace era = 2 if 1992 <= year & year <= 1996
replace era = 3 if 1997 <= year & year <= 2001
replace era = 4 if 2002 <= year & year <= 2006
replace era = 5 if 2007 <= year & year <= 2011
replace era = 6 if 2012 <= year & year <= 2014 
label var era "Era"
label define eralbl 1 " pre 1991", modify
label define eralbl 2 "1992-1996", modify
label define eralbl 3 "1997-2001", modify
label define eralbl 4 "2002-2006", modify
label define eralbl 5 "2007-2011", modify
label define eralbl 6 "2012-2014", modify
label values era eralbl

gen yrpre = era == 2
label var yrpre "year 1992-1996"

gen yrpost = era == 4
label var yrpre "year 2002-2006"

egen tag_country = tag(wbcode)
label var tag_country "Country tag"

/* computing yearly totals */
// variables for which we are computing the totals by year
local totvars "res res_chg debtliab debtliab_chg liab_chg gdp"
// eras for which we compute averages

local eravals "1 2 3 4 5 6"
foreach var of local totvars {
	bysort year split_group: egen `var'_tot = total(`var')
	label var `var'_tot "Yearly total of `var' by group"
	format `var'_tot %7.2f

}

foreach var of local totvars {
	gen `var'_tot_gdp = 100*`var'_tot /gdp_tot
	label var `var'_tot_gdp "Total change in `var' over total GDP"
	format `var'_tot_gdp %7.2f

	bysort era split_group: egen `var'_tot_gdp_era = mean(`var'_tot_gdp)
	label var `var'_tot_gdp_era "Total change in `var' over total GDP"
	format `var'_tot_gdp_era %7.2f
	
	foreach eraval of local eravals {
		gen _tmp_`eraval' = `var'_tot_gdp_era if era == `eraval'
		
		bysort split_group: egen `var'_tot_gdp_era_`eraval' = max(_tmp_`eraval') // copy the mean for all obs. in group
		label var `var'_tot_gdp_era_`eraval' "Total change in `var' over total GDP"
		format `var'_tot_gdp_era_`eraval' %7.2f
		
		drop _tmp_`eraval'
	}
	
}

/* computing era average */
// variables for which we are computing the averages by era
local avgvars "res_gdp res_liab res_debtliab debtliab_gdp"

// eras for which we compute averages
local eravals "1 2 3 4 5 6"

foreach var of local avgvars {
	bysort ifs_code era: egen `var'_avg_era = mean(`var')

	gen _`var'_1 = `var'_avg_era if era == 1 // get mean within era == 1
	bysort ifs_code: egen `var'_old = max(_`var'_1) // copy the mean for all obs.
	format `var'_old %7.2f
	
	gen _`var'_2 = `var'_avg_era if era == 2 // get mean within era == 2
	bysort ifs_code: egen `var'_pre = max(_`var'_2) // copy the mean for all obs.
	format `var'_pre %7.2f
	
	gen _`var'_3 = `var'_avg_era if era == 3 // get mean within era == 3
	bysort ifs_code: egen `var'_btw = max(_`var'_3) // copy the mean for all obs.
	format `var'_btw %7.2f
	
	gen _`var'_4 = `var'_avg_era if era == 4 // get mean within era == 4
	bysort ifs_code: egen `var'_post = max(_`var'_4) // copy the mean for all obs.
	format `var'_post %7.2f

	gen _`var'_5 = `var'_avg_era if era == 5 // get mean within era == 5
	bysort ifs_code: egen `var'_gfc = max(_`var'_5) // copy the mean for all obs.
	format `var'_gfc %7.2f	

	gen _`var'_6 = `var'_avg_era if era == 6 // get mean within era == 6
	bysort ifs_code: egen `var'_now = max(_`var'_6) // copy the mean for all obs.
	format `var'_now %7.2f	
	
	drop _`var'_1 _`var'_2 _`var'_3 _`var'_4 _`var'_5 _`var'_6 // drop these variables used to get the means pre & post

	gen `var'_chg = `var'_post - `var'_pre
	label var `var'_chg "change in avg. `var'"
	format `var'_chg %7.2f

	drop if `var'_chg == . // dismiss cases we don't have data pre or post/
}

// set the dataset as a panel dataset
xtset ifs_code year, yearly


// summary
list wbcode res_gdp_pre res_gdp_post res_gdp_chg res_liab_pre res_liab_post res_liab_chg if (emerging | advanced | baltic | piigs) & tag_country, sepby(split_group) N mean 


// stats

disp("Table: Reserves to GDP")
table country  era if emerging & (era >=2 ), c(mean res_gdp) format(%9.1f) stubwidth(20) cellwidth(20)

disp("Table: Reserves to External Debt Liabilities")
table country  era if emerging & (era >=2 ), c(mean res_debtliab) format(%9.1f) stubwidth(20) cellwidth(20)

disp("Summary: Reserve to GDP")
tabstat res_gdp_pre res_gdp_btw res_gdp_post res_gdp_gfc res_gdp_now if tag_country , by (split_group) stat(mean median N) labelwidth(32) varwidth(16) longstub 

disp("Summary: Reserve to External Liabilities")
tabstat res_liab_pre res_liab_btw res_liab_post res_liab_gfc res_liab_now if tag_country , by (split_group) stat(mean median N) labelwidth(32) varwidth(16) longstub

disp("Summary: Reserve to External Debt Liabilities")
tabstat res_debtliab_pre res_debtliab_btw res_debtliab_post res_debtliab_gfc res_debtliab_now if tag_country , by (split_group) stat(mean median N) labelwidth(32) varwidth(16) longstub

disp("Summary: Change Reserve to GDP")
tabstat res_chg_tot_gdp_era_2 res_chg_tot_gdp_era_4 res_chg_tot_gdp_era_5 if tag_country , by (split_group) stat(mean median N) labelwidth(32) varwidth(16) longstub 

disp("Summary: Change External Debt Liabilities to GDP")
tabstat debtliab_chg_tot_gdp_era_2 debtliab_chg_tot_gdp_era_4 debtliab_chg_tot_gdp_era_5 if tag_country , by (split_group) stat(mean median N) labelwidth(32) varwidth(16) longstub

disp("Summary: Change Total Liabilities to GDP")
tabstat debtliab_chg_tot_gdp_era_2 debtliab_chg_tot_gdp_era_4 debtliab_chg_tot_gdp_era_5 if tag_country , by (split_group) stat(mean median N) labelwidth(32) varwidth(16) longstub

// plots - reserves over gdp
graph bar (median) res_gdp_avg_era if adv_emerging != 3 & (yrpre == 1 | yrpost == 1), over(era, gap(*.10)) over(adv_emerging, relabel(1 "emerging economies" 2 "advanced economies"))  ytitle("percent of GDP") ylabel(,angle(0)) title("Foreign Reserves over GDP")  legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f) ) name(resgdp, replace)

graph save resgdp_plot.gph, asis replace
graph export resgdp_plot.eps, as(eps) preview(on) replace

graph bar (median) res_gdp_avg_era if (adv_emerging == 1 | adv_emerging == 2 | piigs==1) & (yrpre == 1 | yrpost == 1), over(era, label(angle(25) labsize(small)) gap(*.10)) over(adv_emerging, relabel(1 "emerging economies" 2 "advanced economies" 3 "euro area periphery"))  ytitle("percent of GDP") ylabel(,angle(0)) title("Foreign Reserves over GDP")  legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f) ) name(resgdp_giips, replace)

graph save resgdp_giips_plot.gph, asis replace
graph export resgdp_giips_plot.eps, as(eps) preview(on) replace

graph bar (median) res_gdp_avg_era if (split_group == 1 | split_group == 2 | split_group == 3 ) & (era >= 2 & era<= 6), over(era, label(angle(25) labsize(small)) gap(*.10)) over(split_group)  ytitle("percent of GDP") ylabel(,angle(0)) title("Foreign Reserves over GDP")  legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f) ) name(resgdp_baltic, replace)

graph save resgdp_baltic_plot.gph, asis replace
graph export resgdp_baltic_plot.eps, as(eps) preview(on) replace

// plots - reserves over liabilities
graph bar (median) res_liab_avg_era if adv_emerging != 3 & (yrpre == 1 | yrpost == 1), over(era, gap(*.10)) over(adv_emerging, relabel(1 "emerging economies" 2 "advanced economies"))  ytitle("percent of external liabilities") ylabel(,angle(0)) title("Foreign Reserves over External Liabilities") legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f)) name(resliab, replace)

graph save resliab_plot.gph, asis replace
graph export resliab_plot.eps, as(eps) preview(on) replace

graph bar (median) res_liab_avg_era if (adv_emerging == 1 | adv_emerging == 2 | piigs==1) & (yrpre == 1 | yrpost == 1), over(era, label(angle(25) labsize(small)) gap(*.10)) over(adv_emerging, relabel(1 "emerging economies" 2 "advanced economies" 3 "euro area periphery"))  ytitle("percent of liabilities") ylabel(,angle(0)) title("Foreign Reserves over Total Liabilities")  legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f) ) name(resliab_giips, replace)

graph save resliab_giips_plot.gph, asis replace
graph export resliab_giips_plot.eps, as(eps) preview(on) replace

graph bar (median) res_liab_avg_era if (split_group == 1 | split_group == 2 | split_group == 3 ) & (era >= 2 & era<= 6), over(era, label(angle(25) labsize(small)) gap(*.10)) over(split_group)  ytitle("percent of liabilities") ylabel(,angle(0)) title("Foreign Reserves over Total Liabilities")  legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f) ) name(resliab_baltic, replace)

graph save resliab_baltic_plot.gph, asis replace
graph export resliab_baltic_plot.eps, as(eps) preview(on) replace

// plots - reserves over external debt liabilities
graph bar (median) res_debtliab_avg_era if adv_emerging != 3 & (yrpre == 1 | yrpost == 1), over(era, gap(*.10)) over(adv_emerging, relabel(1 "emerging economies" 2 "advanced economies"))  ytitle("percent of external debt") ylabel(,angle(0)) title("Foreign Reserves over External Debt Liabilities") legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f)) name(res_debtliab, replace) 

graph save res_debtliab_plot.gph, asis replace
graph export res_debtliab_plot.eps, as(eps) preview(on) replace

graph bar (median) res_debtliab_avg_era if (adv_emerging == 1 | adv_emerging == 2 | piigs == 1 ) & (yrpre == 1 | yrpost == 1), over(era,  label(angle(25) labsize(small))  gap(*.10)) over(adv_emerging, relabel(1 "emerging economies" 2 "advanced economies" 3 "euro area periphery"))  ytitle("percent of external debt") ylabel(,angle(0)) title("Foreign Reserves over External Debt Liabilities") legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f)) name(res_debtliab_giips, replace)

graph save res_debtliab_giips_plot.gph, asis replace
graph export res_debtliab_giips_plot.eps, as(eps) preview(on) replace

graph bar (median) res_debtliab_avg_era if (split_group == 1 | split_group == 2 | split_group == 3 ) & (era >= 2 & era<= 6), over(era,  label(angle(25) labsize(small))  gap(*.10)) over(split_group)  ytitle("percent of external debt") ylabel(,angle(0)) title("Foreign Reserves over External Debt Liabilities") legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f)) name(res_debtliab_baltic, replace)

graph save res_debtliab_baltic_plot.gph, asis replace
graph export res_debtliab_baltic_plot.eps, as(eps) preview(on) replace

// plots - changes in debt liabilities by group
graph bar (median)  debtliab_chg_tot_gdp_era if (split_group == 1 | split_group == 2 | split_group == 3 ) & (era >= 2 & era<= 6), over(era,  label(angle(25) labsize(small))  gap(*.10)) over(split_group)   ytitle("percent of GDP") ylabel(,angle(0)) title("Change in External Debt Liabilities over Total GDP") legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f)) name(debtliab_chg, replace)

graph save debtliab_chg_plot.gph, asis replace
graph export debtliab_chg_plot.eps, as(eps) preview(on) replace

// plots - changes in total liabilities by group
graph bar (median)  liab_chg_tot_gdp_era if (split_group == 1 | split_group == 2 | split_group == 3 ) & (era >= 2 & era<= 6), over(era,  label(angle(25) labsize(small))  gap(*.10)) over(split_group)   ytitle("percent of GDP") ylabel(,angle(0)) title("Change in External Liabilities over Total GDP") legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f)) name(liab_chg, replace)

graph save liab_chg_plot.gph, asis replace
graph export liab_chg_plot.eps, as(eps) preview(on) replace

// plots - total debt liabilities by group
graph bar (median)  debtliab_tot_gdp_era if (split_group == 1 | split_group == 2 | split_group == 3 ) & (era >= 2 & era<= 6), over(era,  label(angle(25) labsize(small))  gap(*.10)) over(split_group)   ytitle("percent of GDP") ylabel(,angle(0)) title("Total External Debt Liabilities over Total GDP") legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f)) name(debtliab_tot, replace)

graph save debtliab_tot_plot.gph, asis replace
graph export debtliab_tot_plot.eps, as(eps) preview(on) replace

save iip_hk_v`today'.dta, replace

log close





